@@ -4,16 +4,16 @@ old.contr = options()$contrasts
 options(contrasts=c("contr.sum", "contr.sum"))
 
   for (j in 1 :(firstvar-1))  donnee[,j] <- as.factor(donnee[,j])
-  formul = as.formula(formul)
+  formul = as.formula(paste(formul, collapse = " "))
   lab.sauv <- lab <- colnames(donnee)
   for (i in 1:length(lab)) lab[i]=gsub(" ",".",lab[i])
   colnames(donnee) = lab
   equation <- as.character(formul)
 
-  Terms=attr(terms(as.formula(equation)),"term.labels")
+  Terms=attr(terms(as.formula(paste(equation, collapse = " "))),"term.labels")
   equation = paste("~",Terms[1])
   if (length(Terms) > 1) for (i in 2:length(Terms)) equation <- paste(equation,"+",Terms[i])
-  equation <- as.character(as.formula(equation))
+  equation <- as.character(as.formula(paste(equation, collapse = " ")))
 
   dim.donnee <- ncol(donnee)
   for (i in 1:dim.donnee) {
@@ -26,7 +26,7 @@ options(contrasts=c("contr.sum", "contr.sum"))
 
   for (varendo in firstvar:lastvar) {
       formule <- paste(lab[varendo],"~",equation[2])
-    formule <- as.formula(formule)
+      formule <- as.formula(paste(formule, collapse = " "))
     aux1 <- aov( formule , data = donnee, subset=subset,na.action =na.exclude)
     aux <- summary(aux1)[[1]]
     perf[varendo-firstvar+1,] <- aux[-nrow(aux),5]
