@@ -1,4 +1,4 @@
-"plotellipseinter" <- function(mat,alpha=0.05,coord=c(1,2),nbgroup=1,moy=TRUE,eig,cex=1,color=NULL,title=NULL){
+"plotellipseinter" <- function(mat,alpha=0.05,coord=c(1,2),nbgroup=1,moy=TRUE,eig,cex=1,color=NULL,title=NULL,graph.type=c("ggplot","classic")){
 
 #################################################################
 "ellipse2" <- function(loc, cov,alpha)
@@ -23,6 +23,7 @@ if (length(color)==0) color = c("black","red","green3","blue",
   "lightblue","darkkhaki", "darkmagenta","darkolivegreen","lightcyan", "darkorange",
   "darkorchid","darkred","darksalmon","darkseagreen","darkslateblue","darkslategray","darkslategrey",
   "darkturquoise","darkviolet", "lightgray","lightsalmon","lightyellow", "maroon")
+graph.type <- match.arg(graph.type[1],c("ggplot","classic"))
 if (moy ==TRUE) {
   matP=cbind.data.frame(mat$moy$P[,coord],mat$moy$P[,ncol(mat$moy$P)])
   matPJ=cbind.data.frame(mat$moy$PJ[,coord],mat$moy$PJ[,ncol(mat$moy$PJ)])
@@ -54,7 +55,10 @@ maxx <- max(coord.ellipse.a.tracer[,1+2*(0:(nbp-1))],na.rm=TRUE)
 miny <- min(coord.ellipse.a.tracer[,2*(1:nbp)],na.rm=TRUE)
 maxy <- max(coord.ellipse.a.tracer[,2*(1:nbp)],na.rm=TRUE)
 
-  plot(0, 0, xlab = paste("Dim ",coord[1]," (",eig[coord[1],2],"%)",sep=""), ylab = paste("Dim ",coord[2]," (",eig[coord[2],2],"%)",sep=""), xlim = c(minx*1.05,maxx*1.05), ylim = c(1.05*miny,1.05*maxy), col = "white", asp=1)
+lab.x <- paste0("Dim ",coord[1]," (",format(eig[coord[1],2],nsmall=2,digits=2),"%)")
+lab.y <- paste0("Dim ",coord[2]," (",format(eig[coord[2],2],nsmall=2,digits=2),"%)")
+if (graph.type=="classic"){
+  plot(0, 0, xlab = lab.x, ylab = lab.y, xlim = c(minx*1.05,maxx*1.05), ylim = c(1.05*miny,1.05*maxy), col = "white", asp=1)
   if (is.null(title)){
     if (moy==TRUE) title(main = "Confidence ellipses for the mean points")
     if (moy==FALSE) title(main = "Confidence ellipses for the partial points")
@@ -73,4 +77,26 @@ maxy <- max(coord.ellipse.a.tracer[,2*(1:nbp)],na.rm=TRUE)
       lines(coord.ellipse.a.tracer[,(1+2*((i+(j-1)*nbprod)-1)):(2*(i+(j-1)*nbprod))],col=color[i],lty=j)
     }
   }
+} else{
+  gg_graph <- ggplot()+ coord_fixed(ratio = 1) +  xlim(c(minx,maxx)) + ylim(c(miny,maxy)) +
+    geom_hline(yintercept = 0,lty=2) + geom_vline(xintercept = 0,lty=2) +
+    theme_light()+ theme(axis.title = element_text(hjust = 1, face = 2), plot.title = element_text(hjust = 0.5, face = 2))
+    if (is.null(title) & moy==TRUE) gg_graph <- gg_graph + labs(x = lab.x, y= lab.y,title = "Confidence ellipses for the mean points")
+    if (is.null(title) & moy==FALSE) gg_graph <- gg_graph + labs(x = lab.x, y= lab.y,title = "Confidence ellipses for the partial points")
+    if (!is.null(title)) gg_graph <- gg_graph + labs(x = lab.x, y= lab.y,title = title)
+    if (moy==FALSE){
+      gg_graph <- gg_graph + geom_point(aes(x=matmoyP[,1], y=matmoyP[,2]),color = color[1:nbprod],pch=15,size=0.8*cex*4)
+      gg_graph <- gg_graph + ggrepel::geom_text_repel(aes(x=matmoyP[,1], y=matmoyP[,2], label=matmoyP[,ncol(matmoyP)]), color = color[1:nbprod])
+    }
+    if (moy==TRUE)  gg_graph <- gg_graph + ggrepel::geom_text_repel(aes(x=matP[,1], y=matP[,2], label=matP[,ncol(matP)]), color = color[1:nbprod])
+    gg_graph <- gg_graph + geom_point(aes(x=matP[,1], y=matP[,2]),color=rep(color[1:nbprod],nbgroup),pch=20,size=0.8*cex*3)
+    for (j in 1:nbgroup){
+      for (i in 1:nbprod)  gg_graph <- gg_graph + geom_path(aes_string(x=coord.ellipse.a.tracer[,2*(i+(j-1)*nbprod)-1],y=coord.ellipse.a.tracer[,2*(i+(j-1)*nbprod)]), color =color[i],lty=j)
+    }
+    if (moy==FALSE){
+      group <- as.factor(rep(1:nbgroup,each=nbprod))
+      gg_graph <- gg_graph + geom_segment(aes(x=matP[,1],xend=rep(matmoyP[,1],nbgroup),y=matP[,2],yend=rep(matmoyP[,2],nbgroup),lty=group),color=rep(color[1:nbprod],nbgroup)) + theme(legend.position="bottom")
+    }
+    return(gg_graph)
+  }
 }
